@@ -1,11 +1,19 @@
-# -----------------------------------------------------------------------------
-# Copyright (c) Equinor ASA. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
-# -----------------------------------------------------------------------------
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 """config default command"""
 
+from pathlib import Path
+
 import click
 
 from osducli.click_cli import State, global_params
@@ -41,7 +49,11 @@ def config_default(state: State):
     else:
         config_file = state.config_path
     if config_file:
-        print("TODO CHeck Path")
+        path = Path(config_file)
+        if not path.is_file():
+            print(
+                "The specified file was not found. Run osdu config update to add configuration values."
+            )
         set_default_config_path(config_file)
     else:
         print("No changes made!")
