@@ -1,8 +1,14 @@
-# -----------------------------------------------------------------------------
-# Copyright (c) Equinor ASA. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
-# -----------------------------------------------------------------------------
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 """Dataload ingest command"""
 
@@ -30,6 +36,7 @@ from osducli.util.exceptions import CliError
 from osducli.util.file import get_files_from_path
 
 logger = get_logger(__name__)
+VERIFY_BATCH_SIZE = 200
 
 
 # click entry point
@@ -55,7 +62,7 @@ logger = get_logger(__name__)
 @click.option(
     "-rl",
     "--runid-log",
-    help="Path to a file containing run ids to get status of (see dataload ingest -h).",
+    help="Path to a file to save run ids to to later check status of (see dataload status -h).",
 )
 @click.option(
     "-w", "--wait", help="Whether to wait for runs to complete.", is_flag=True, show_default=True
@@ -113,10 +120,10 @@ def ingest(
     return runids
 
 
-def _ingest_files(  # noqa:C901 pylint: disable=R0912
+def _ingest_files(  # noqa:C901 pylint: disable=R0912,too-many-nested-blocks
     config: CLIConfig, manifest_files, files, runid_log, batch_size, wait, skip_existing, simulate
 ):
-    logger.info("Files list: %s", manifest_files)
+    logger.debug("Files list: %s", manifest_files)
     runids = []
     runid_log_handle = None
     try:
@@ -132,45 +139,50 @@ def _ingest_files(  # noqa:C901 pylint: disable=R0912
             # Note this code currently assumes only one of MasterData, ReferenceData or Data exists!
             if not manifest:
                 logger.error("Error with file %s. File is empty.", filepath)
-            elif "ReferenceData" in manifest and len(manifest["ReferenceData"]) > 0:
-                _update_legal_and_acl_tags_all(config, manifest["ReferenceData"])
-                if batch_size is None and not skip_existing:
+            else:
+                logger.info("Processing %s.", filepath)
+
+                if "ReferenceData" in manifest and len(manifest["ReferenceData"]) > 0:
+                    _update_legal_and_acl_tags_all(config, manifest["ReferenceData"])
+                    if batch_size is None and not skip_existing:
+                        _create_and_submit(config, manifest, runids, runid_log_handle, simulate)
+                    else:
+                        data_objects += manifest["ReferenceData"]
+                        file_batch_size = (
+                            len(data_objects) if skip_existing and not batch_size else batch_size
+                        )
+                        data_objects = _process_batch(
+                            config,
+                            file_batch_size,
+                            "ReferenceData",
+                            data_objects,
+                            runids,
+                            runid_log_handle,
+                            skip_existing,
+                            simulate,
+                        )
+                elif "MasterData" in manifest and len(manifest["MasterData"]) > 0:
+                    _update_legal_and_acl_tags_all(config, manifest["MasterData"])
+                    if batch_size is None and not skip_existing:
+                        _create_and_submit(config, manifest, runids, runid_log_handle, simulate)
+                    else:
+                        data_objects += manifest["MasterData"]
+                        file_batch_size = (
+                            len(data_objects) if skip_existing and not batch_size else batch_size
+                        )
+                        data_objects = _process_batch(
+                            config,
+                            file_batch_size,
+                            "MasterData",
+                            data_objects,
+                            runids,
+                            runid_log_handle,
+                            skip_existing,
+                            simulate,
+                        )
+                elif "Data" in manifest:
+                    _update_work_products_metadata(config, manifest["Data"], files, simulate)
                     _create_and_submit(config, manifest, runids, runid_log_handle, simulate)
-                else:
-                    data_objects += manifest["ReferenceData"]
-                    if skip_existing and not batch_size:
-                        batch_size = len(data_objects)
-                    data_objects = _process_batch(
-                        config,
-                        batch_size,
-                        "ReferenceData",
-                        data_objects,
-                        runids,
-                        runid_log_handle,
-                        skip_existing,
-                        simulate,
-                    )
-            elif "MasterData" in manifest and len(manifest["MasterData"]) > 0:
-                _update_legal_and_acl_tags_all(config, manifest["MasterData"])
-                if batch_size is None and not skip_existing:
-                    _create_and_submit(config, manifest, runids, runid_log_handle, simulate)
-                else:
-                    data_objects += manifest["MasterData"]
-                    if skip_existing and not batch_size:
-                        batch_size = len(data_objects)
-                    data_objects = _process_batch(
-                        config,
-                        batch_size,
-                        "MasterData",
-                        data_objects,
-                        runids,
-                        runid_log_handle,
-                        skip_existing,
-                        simulate,
-                    )
-            elif "Data" in manifest:
-                _update_work_products_metadata(config, manifest["Data"], files, simulate)
-                _create_and_submit(config, manifest, runids, runid_log_handle, simulate)
     finally:
         if runid_log_handle is not None:
             runid_log_handle.close()
@@ -192,7 +204,7 @@ def _process_batch(
         for data in data_objects:
             if "id" in data:
                 ids_to_verify.append(data.get("id"))
-        batch_verify(config, batch_size, ids_to_verify, found, not_found, True)
+        batch_verify(config, VERIFY_BATCH_SIZE, ids_to_verify, found, not_found, True)
         data_objects = [
             data for data in data_objects if "id" in data and data.get("id") in not_found
         ]
